//------------------------------------------------------------------------------
// MapperTypes.cs
//
// Ben Axelrod  -  08/2007
//
//------------------------------------------------------------------------------

using Microsoft.Ccr.Core;
using Microsoft.Dss.Core.Attributes;
using Microsoft.Dss.ServiceModel.Dssp;
using System;
using System.Collections.Generic;
using W3C.Soap;

// for Http Operations
using System.Net;
using System.Collections.Specialized;
using Microsoft.Dss.Core.DsspHttp;
using Microsoft.Dss.Core.DsspHttpUtilities;
using System.Drawing;

namespace Robotics.Mapper
{

    /// <summary>
    /// Mapper Contract
    /// </summary>
    public sealed class Contract
    {
        /// The Unique Contract Identifier for the Mapper service
        public const String Identifier = "http://schemas.roboben.com/2007/01/mapper.html";
    }

    /// <summary>
    /// Mapper State
    /// </summary>
    [DataContract()]
    public class MapperState
    {
        [DataMember]
        public float LatestX;

        [DataMember]
        public float LatestZ;

        [DataMember]
        public float LatestAngle;

        [DataMember]
        public int[] LatestDistanceMeasurements;

        [DataMember]
        public List<PointList> AllDistanceMeasurements;
    }

    [DataContract]
    public class PointList
    {
        [DataMember]
        public List<Point> Points;

        public PointList() { }
        public PointList(List<Point> p)
        {
            this.Points = p;
        }
    }

    /// <summary>
    /// Mapper Operations
    /// </summary>
    public class MapperOperations : PortSet<
        DsspDefaultLookup, 
        DsspDefaultDrop, 
        Get, 
        Replace, 
        HttpGet>
    {
    }

    /// <summary>
    /// Get the state value
    /// </summary>
    public class Get : Get<GetRequestType, PortSet<MapperState, Fault>>
    {
    }

    /// <summary>
    /// Replace the state value
    /// </summary>
    public class Replace : Replace<MapperState, PortSet<DefaultReplaceResponseType, Fault>>
    {
    }


}
