//------------------------------------------------------------------------------
// SimRobotTypes.cs
//
// Ben Axelrod  -  08/2007
//
//------------------------------------------------------------------------------
using Microsoft.Ccr.Core;
using Microsoft.Dss.Core.Attributes;
using Microsoft.Dss.ServiceModel.Dssp;
using System;
using System.Collections.Generic;
using W3C.Soap;
using simrobot = Robotics.SimRobot;
using Microsoft.Robotics.PhysicalModel;

using sicklrf = Microsoft.Robotics.Services.Sensors.SickLRF.Proxy;

namespace Robotics.SimRobot
{
    
    /// <summary>
    /// SimRobot Contract
    /// </summary>
    public sealed class Contract
    {
        /// The Unique Contract Identifier for the SimRobot service
        public const String Identifier = "http://schemas.tempuri.org/2007/01/simrobot.html";
    }
    /// <summary>
    /// Sim Robot State
    /// </summary>
    [DataContract()]
    public class SimRobotState
    {
        [DataMember]
        public Pose robotPose;

        [DataMember]
        public DateTime poseUpdated;
    }

    /// <summary>
    /// Sim Robot Operations
    /// </summary>
    public class SimRobotOperations : PortSet<
        DsspDefaultLookup, 
        DsspDefaultDrop, 
        Get,
        Replace,
        Subscribe>
    {
    }

    /// <summary>
    /// Get
    /// </summary>
    public class Get : Get<GetRequestType, PortSet<SimRobotState, Fault>>
    {
    }

    /// <summary>
    /// Replace
    /// </summary>
    public class Replace : Replace<SimRobotState, PortSet<DefaultReplaceResponseType, Fault>>
    {
        public Replace() { }

        public Replace(SimRobotState r)
        {
            this.Body = r;
        }
    }

    /// <summary>
    /// subscribe to the pose updates of SimRobot
    /// </summary>
    public class Subscribe : Subscribe<SubscribeRequestType, PortSet<SubscribeResponseType, Fault>>
    {
    }
}
